@@ -1,12 +1,12 @@
 from django.db import models
-from plicata.books.models import Book
+from plicta.books.models import Book
 
 
 class Character(models.Model):
     name = models.CharField(max_length=80, unique=True)
     firstname = models.CharField(max_length=80,blank=True,null=True)
     lastname = models.CharField(max_length=80,blank=True,null=True)
-    book = models.ManyToManyField(Book, blank=True,null=True)
+    books = models.ManyToManyField(Book, blank=True,null=True, related_name='character_book')
     bioshort = models.CharField(max_length=500,blank=True,null=True)
     biolong = models.TextField(blank=True,null=True)
     def __unicode__(self):
